A dataset containing the a simple example of cytometry data
citrus.combinedFCSSetA large citrus.combinedFCSSet object with 5 elements:
Toy data set for cytometry
Names of channels for measured parameters included in toy cytmetry data set
ID numbers for each file included in toy cytometry data set
Names of files included in toy cytmetry data set
Names of measured channels in toy cytmetry data set