Learn R Programming

mineCitrus (version 1.0.0)

citrus.foldClustering: Clustering data for example of Citrus data set from nolanlab/citrus

Description

A dataset containing the clustering of different cell groups

Usage

citrus.foldClustering

Arguments

Format

A large citrus.foldClustering object with 5 elements:

allClustering

A list describing which events belong to which clusters

foldClustering

A list describing which events belong to which clusters for each fold

foldMappingAssignments

A list describing assignments with fold clustering

folds

Descriptions of each data clustering

nFolds

The number of times data is clustered

...