A dataset containing the clustering of different cell groups
citrus.foldClusteringA large citrus.foldClustering object with 5 elements:
A list describing which events belong to which clusters
A list describing which events belong to which clusters for each fold
A list describing assignments with fold clustering
Descriptions of each data clustering
The number of times data is clustered